<?php

namespace Drupal\sfc_example\Plugin\SingleFileComponent;

use Drupal\Core\Form\FormStateInterface;
use Drupal\sfc\ComponentBase;

/**
 * Contains an example component that provides a block.
 *
 * @SingleFileComponent(
 *   id = "dice_roll",
 *   group = "Example",
 *   block = {
 *     "admin_label" = "Dice roll",
 *     "category" = "Example components",
 *   }
 * )
 */
class DiceRoll extends ComponentBase {

  const TEMPLATE = <<<TWIG
<p class="dice-roll">You rolled a {{ roll }}!</p>
TWIG;

  const CSS = <<<CSS
.dice-roll {
  font-size: 20px;
}
CSS;

  /**
   * {@inheritdoc}
   */
  public function buildContextForm(array $form, FormStateInterface $form_state, array $default_values = []) {
    $form['sides'] = [
      '#type' => 'number',
      '#title' => $this->t('Sides'),
      '#description' => $this->t('The number of sides for the die.'),
      '#required' => TRUE,
      '#default_value' => isset($default_values['sides']) ? $default_values['sides'] : 6,
      '#min' => 2,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareContext(array &$context) {
    $context['cache'] = ['#cache' => ['max-age' => 0]];
    $context['sides'] = isset($context['sides']) ? $context['sides'] : 6;
    $context['roll'] = rand(1, $context['sides']);
  }

}
