<?php

namespace Drupal\Tests\sfc_example\Kernel;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormState;
use Drupal\KernelTests\KernelTestBase;
use Drupal\sfc_example\Plugin\SingleFileComponent\BoldFormatter;
use Drupal\Tests\sfc\Kernel\ComponentTestTrait;

/**
 * Tests the BoldFormatter component.
 *
 * @group sfc_example
 */
class BoldFormatterTest extends KernelTestBase {

  use ComponentTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'sfc',
    'sfc_example',
  ];

  /**
   * Tests bold_formatter form methods.
   */
  public function testForm() {
    $file_system = $this->createMock(FileSystemInterface::class);
    $component = new BoldFormatter([], 'bold_formatter', [], FALSE, 'vfs:/', $file_system);
    $form = $component->buildContextForm([], new FormState(), []);
    $this->assertEquals($form['text']['#default_value'], '');
    $form = $component->buildContextForm([], new FormState(), [
      'text' => 'Foo',
    ]);
    $this->assertEquals($form['text']['#default_value'], 'Foo');
  }

  /**
   * Tests ::testPrepareContext.
   */
  public function testPrepareContext() {
    $file_system = $this->createMock(FileSystemInterface::class);
    $component = new BoldFormatter([], 'bold_formatter', [], FALSE, 'vfs:/', $file_system);
    $item = $this->createMock(FieldItemInterface::class);
    $item->method('__get')->willReturn('test');
    $context = [
      'item' => $item,
    ];
    $component->prepareContext($context);
    $this->assertEquals('test', $context['text']);
  }

}
