<?php

namespace Drupal\Tests\sfc_example\Kernel;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormState;
use Drupal\KernelTests\KernelTestBase;
use Drupal\sfc_example\Plugin\SingleFileComponent\DiceRoll;
use Drupal\Tests\sfc\Kernel\ComponentTestTrait;

/**
 * Tests the DiceRoll component.
 *
 * @group sfc_example
 */
class DiceRollTest extends KernelTestBase {

  use ComponentTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'sfc',
    'sfc_example',
  ];

  /**
   * Tests rendering the dice_roll component.
   */
  public function testRender() {
    $this->assertRegExp('/<p class="dice-roll">You rolled a [1-9]!<\/p>/', $this->renderComponent('dice_roll', []));
    $this->assertRegExp('/<p class="dice-roll">You rolled a [1-9]{1,2}[0]?!<\/p>/', $this->renderComponent('dice_roll', [
      'sides' => 99,
    ]));
  }

  /**
   * Tests dice_roll form methods.
   */
  public function testForm() {
    $file_system = $this->createMock(FileSystemInterface::class);
    $component = new DiceRoll([], 'dice_roll', [], FALSE, 'vfs:/', $file_system);
    $form = $component->buildContextForm([], new FormState(), []);
    $this->assertEquals($form['sides']['#default_value'], 6);
    $form = $component->buildContextForm([], new FormState(), [
      'sides' => 99,
    ]);
    $this->assertEquals($form['sides']['#default_value'], 99);
  }

}
