<?php

namespace Drupal\Tests\sfc_example\Kernel;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Session\AccountProxy;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Session\UserSession;
use Drupal\KernelTests\KernelTestBase;
use Drupal\sfc_example\Plugin\SingleFileComponent\SayHello;
use Drupal\Tests\sfc\Kernel\ComponentTestTrait;

/**
 * Tests the SayHello component.
 *
 * @group sfc_example
 */
class SayHelloTest extends KernelTestBase {

  use ComponentTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'sfc',
    'sfc_example',
  ];

  /**
   * This test doesn't mock anything and is more like a light integration test.
   */
  public function testRenderIntegration() {
    $session = new UserSession([
      'name' => 'Default',
    ]);
    $proxy = new AccountProxy();
    $proxy->setAccount($session);
    \Drupal::currentUser()->setAccount($proxy);
    $this->assertEquals('<p class="say-hello">Hello Default!</p>', $this->renderComponent('say_hello', []));
    $this->assertEquals('<p class="say-hello">Hello Sam!</p>', $this->renderComponent('say_hello', [
      'name' => 'Sam',
    ]));
  }

  /**
   * This test uses mocking to test the component.
   */
  public function testRenderMock() {
    $file_system = $this->createMock(FileSystemInterface::class);
    $current_user = $this->createMock(AccountProxyInterface::class);
    $current_user->method('getDisplayName')->willReturn('Default');
    $component = new SayHello([], 'say_hello', [], FALSE, 'vfs:/', $file_system, $current_user);
    $this->assertEquals('<p class="say-hello">Hello Default!</p>', $this->renderComponentObject($component, []));
    $this->assertEquals('<p class="say-hello">Hello Sam!</p>', $this->renderComponentObject($component, [
      'name' => 'Sam',
    ]));
  }

}
