<?php

namespace Drupal\Tests\sfc_example\Kernel;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormState;
use Drupal\KernelTests\KernelTestBase;
use Drupal\sfc_example\Plugin\SingleFileComponent\TwoColumnLayout;
use Drupal\Tests\sfc\Kernel\ComponentTestTrait;

/**
 * Tests the TwoColumnLayout component.
 *
 * @group sfc_example
 */
class TwoColumnLayoutTest extends KernelTestBase {

  use ComponentTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'sfc',
    'sfc_example',
  ];

  /**
   * Tests rendering the two_column_flexible component.
   */
  public function testRender() {
    $this->assertEquals('<div class="two-column sizing-50-50">
  <div class="left">
    
  </div>
  <div class="right">
    
  </div>
</div>', $this->renderComponent('two_column_flexible', []));

    $context = [
      'sizing' => 'foo',
      'content' => [
        'left' => 'Left side',
        'right' => 'Right side',
      ],
    ];
    $this->assertEquals('<div class="two-column sizing-foo">
  <div class="left">
    Left side
  </div>
  <div class="right">
    Right side
  </div>
</div>', $this->renderComponent('two_column_flexible', $context));
  }

  /**
   * Tests two_column_flexible form methods.
   */
  public function testForm() {
    $file_system = $this->createMock(FileSystemInterface::class);
    $component = new TwoColumnLayout([], 'two_column_flexible', [], FALSE, 'vfs:/', $file_system);
    $form = $component->buildContextForm([], new FormState(), []);
    $this->assertEquals($form['sizing']['#default_value'], '50-50');
    $form = $component->buildContextForm([], new FormState(), [
      'sizing' => '30-70',
    ]);
    $this->assertEquals($form['sizing']['#default_value'], '30-70');
  }

}
