<?php

namespace Drupal\sfc\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Derives SFC plugin definitions from *.sfc files.
 */
class SimpleComponentDeriver extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected $themeHandler;

  /**
   * SimpleComponentDeriver constructor.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   The theme handler.
   */
  public function __construct(ModuleHandlerInterface $module_handler, ThemeHandlerInterface $theme_handler) {
    $this->moduleHandler = $module_handler;
    $this->themeHandler = $theme_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('module_handler'),
      $container->get('theme_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $directories = array_merge($this->moduleHandler->getModuleDirectories(), $this->themeHandler->getThemeDirectories());
    foreach ($directories as $project => $directory) {
      foreach (file_scan_directory($directory . '/components/', '/^.*\.sfc/') as $file) {
        $id = str_replace('.sfc', '', $file->filename);
        $this->derivatives[$id] = $base_plugin_definition;
        $this->derivatives[$id]['simple_file'] = $file->uri;
        $this->derivatives[$id]['alt_id'] = $id;
        $this->derivatives[$id]['provider'] = $project;
        $this->derivatives[$id] = array_merge($this->derivatives[$id], $this->getDefinitionAdditions($file->uri));
      }
    }
    return $this->derivatives;
  }

  /**
   * Gets plugin definition additions defined by a simple component file.
   *
   * This is in a separate function to avoid variables in the .sfc file
   * polluting the ::getDerivativeDefinitions scope.
   *
   * @param string $filename
   *   The simple component filename.
   *
   * @return array
   *   An array representing the plugin definition additions.
   */
  protected function getDefinitionAdditions($filename) {
    $definition = [];
    ob_start();
    require $filename;
    ob_end_clean();
    return $definition;
  }

}
