<?php

namespace Drupal\sfc;

use Twig\TwigFunction;
use Drupal\Component\Plugin\PluginManagerInterface;

/**
 * Contains custom Twig integrations for the Single File Components module.
 */
class TwigExtension extends \Twig_Extension {

  /**
   * The plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $manager;

  /**
   * TwigExtension constructor.
   *
   * @param \Drupal\Component\Plugin\PluginManagerInterface $manager
   *   The plugin manager.
   */
  public function __construct(PluginManagerInterface $manager) {
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new TwigFunction('sfc_prepare_context', [$this, 'prepareContext'], ['needs_context' => TRUE]),
    ];
  }

  /**
   * Allows component plugins to modify the template context.
   *
   * @param array &$context
   *   The context.
   * @param string $id
   *   The plugin ID.
   */
  public function prepareContext(array &$context, $id) {
    /** @var \Drupal\sfc\ComponentInterface $component */
    $component = $this->manager->createInstance($id);
    $component->prepareContext($context);
  }

}
