<?php

namespace Drupal\Tests\sfc\Kernel;

use Drupal\Core\Form\FormState;
use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the basic behavior of simple components.
 *
 * @coversDefaultClass \Drupal\sfc\Plugin\SingleFileComponent\SimpleComponent
 *
 * @group sfc
 */
class SimpleComponentTest extends KernelTestBase {

  use ComponentTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'sfc',
    'sfc_test',
  ];

  /**
   * Tests that a simple component renders properly.
   */
  public function testRender() {
    $this->assertEquals('<div class="simple-test">Default value</div>', $this->renderComponent('simple_test', []));
    $this->assertEquals('<div class="simple-test">Click me</div>', $this->renderComponent('simple_test', [
      'message' => 'Click me',
    ]));
    // Test the output CSS/JS.
    /** @var \Drupal\Component\Plugin\PluginManagerInterface $manager */
    $manager = \Drupal::service('plugin.manager.single_file_component');
    $component = $manager->createInstance('simple_assets');
    $this->assertTrue($component->shouldWriteAssets());
    $component->writeAssets();
    $this->assertContains('foo/bar', $component->getLibrary()['dependencies']);
    $this->assertFileExists('public://sfc/components/simple_assets/simple_assets.css');
    $this->assertFileExists('public://sfc/components/simple_assets/simple_assets.js');
    $this->assertContains('.foo {', file_get_contents('public://sfc/components/simple_assets/simple_assets.css'));
    $js = file_get_contents('public://sfc/components/simple_assets/simple_assets.js');
    $this->assertContains("alert('foo');", $js);
    $this->assertContains("alert('bar');", $js);
    $this->assertContains("alert('baz');", $js);
    // Test an empty template.
    $this->assertEquals('', $this->renderComponent('simple_empty', []));
  }

  /**
   * Tests that form methods work as expected.
   */
  public function testForm() {
    /** @var \Drupal\Component\Plugin\PluginManagerInterface $manager */
    $manager = \Drupal::service('plugin.manager.single_file_component');
    $component = $manager->createInstance('simple_block');
    $form = [];
    $form_state = new FormState();
    $form = $component->buildContextForm($form, $form_state, []);
    $this->assertNotEmpty($form);
    $form['message']['#parents'] = [];
    $form_state->setValue('message', 'test');
    $component->validateContextForm($form, $form_state);
    $this->assertNotEmpty($form_state->hasAnyErrors());
    $form_state->setValue('message', 'changeme');
    $component->submitContextForm($form, $form_state);
    $this->assertEquals('changed', $form_state->getValue('message'));
  }

  /**
   * Tests that definition additions work as expected.
   */
  public function testDefinitionAdditions() {
    /** @var \Drupal\sfc\Plugin\Block\ComponentBlock $block */
    $block = \Drupal::service('plugin.manager.block')->createInstance('single_file_component_block:simple_block');
    $renderer = \Drupal::service('renderer');
    $build = $block->build();
    $render = $renderer->renderPlain($build);
    $this->assertEquals('<div class="simple-block">Default value</div>', $render);
  }

}
